over this:
.
getElementsByTagNameNS instead of getElementsByTagName
(see also "SVG: Namespace Crash Course" in the references).
plotmath is not supported.
dev.copy - the functions to add tool tips and
hyperlinks are ignored by other devices.
SVG_footer() in src/devSVG.c) - currently the vertical
spacing (the 'height' and 'y' attributes) is somewhat ad-hoc (coded
by trial and error, and may not work for all font sizes).
plotmath.
&\#x3b1;.
The symbols for Unicode are described here:
http://www.unicode.org/charts/symbols.html.
SVG: Namespaces Crash Course http://developer.mozilla.org/en/docs/SVG\_Namespace\_Tips\_(external)
"SVG Essentials", J. David Eisenberg, O'Reilly and Associates, 2002.
Cairo is another device for R that can produce SVG
graphics; see http://www.rforge.net/Cairo. However, it doesn't appear to support tooltips.